diff decoders/mikmod.c @ 221:c9772a9f5271

Initial implementation or stubs for rewind method. Other cleanups.
author Ryan C. Gordon <icculus@icculus.org>
date Thu, 17 Jan 2002 20:53:53 +0000
parents b35c04e4691e
children d3dc34315ac7
line wrap: on
line diff
--- a/decoders/mikmod.c	Thu Jan 17 20:53:03 2002 +0000
+++ b/decoders/mikmod.c	Thu Jan 17 20:53:53 2002 +0000
@@ -50,6 +50,7 @@
 static int MIKMOD_open(Sound_Sample *sample, const char *ext);
 static void MIKMOD_close(Sound_Sample *sample);
 static Uint32 MIKMOD_read(Sound_Sample *sample);
+static int MIKMOD_rewind(Sound_Sample *sample);
 
 static const char *extensions_mikmod[] =
 {
@@ -83,11 +84,12 @@
         "http://www.mikmod.org/"
     },
 
-    MIKMOD_init,       /*  init() method */
-    MIKMOD_quit,       /*  quit() method */
-    MIKMOD_open,       /*  open() method */
-    MIKMOD_close,      /* close() method */
-    MIKMOD_read        /*  read() method */
+    MIKMOD_init,       /*   init() method */
+    MIKMOD_quit,       /*   quit() method */
+    MIKMOD_open,       /*   open() method */
+    MIKMOD_close,      /*  close() method */
+    MIKMOD_read,       /*   read() method */
+    MIKMOD_rewind      /* rewind() method */
 };
 
 
@@ -282,6 +284,17 @@
     return((Uint32) VC_WriteBytes(internal->buffer, internal->buffer_size));
 } /* MIKMOD_read */
 
+
+static int MIKMOD_rewind(Sound_Sample *sample)
+{
+    /* !!! FIXME. */
+    SNDDBG(("MIKMOD_rewind(): Write me!\n"));
+    assert(0);
+    return(0);
+} /* MIKMOD_rewind */
+
+
+
 #endif /* SOUND_SUPPORTS_MIKMOD */